#ifndef _PYGAME2_DOCBASE_H_
#define _PYGAME2_DOCBASE_H_

#define DOC_BASE "Vector math module for Pygame2"
#define DOC_BASE_VECTOR_FROM_POLAR "vector_from_polar (p1, p2) -> Vector2\n\nCreates a 2D vector from the passed polar coordinates."
#define DOC_BASE_VECTOR_FROM_SPHERICAL "vector_from_spherical (p1, p2, p3) -> Vector2\n\nCreates a 3D vector from the passed spherical coordinates."
#define DOC_BASE_VECTOR "Vector (elements) -> Vector\n\nCreates a new Vector with the specified elements or dimension.\n\nCreates a new n-dimensional Vector. *elements* can be either a sequence of\nnumbers representing the values for each dimension or a positive integer\nto create an empty vector with *elements* dimensions."
#define DOC_BASE_VECTOR_DIMENSION "Gets the dimensions of the Vector."
#define DOC_BASE_VECTOR_LENGTH "Gets the length of the Vector."
#define DOC_BASE_VECTOR_LENGTH_SQUARED "Gets the length of the Vector."
#define DOC_BASE_VECTOR_EPSILON "Gets or sets the exactness delta of the Vector.\n\nepsilon represents a small fractional value to come around\nrounding issues on floating point calculations. It is usually used\nto soothe rounding differences and thus to allow the system to\nreturn an appropriate state, with a small tradeoff for the\nexactness.\n\n**Example:** \n\n(0.0000000000001 - 0.0000000000009) == 0.0\n\nGiven that epsilon is large enough, the above calculation will be\ntrue. To get over rounding issues on vector operations with small\nfractional parts or to make them more exact, the concrete epsilon\nvalue can be freely adjusted."
#define DOC_BASE_VECTOR_ELEMENTS "Gets or sets the elements of the Vector.\n\nThis will only set a maximum of dimension values."
#define DOC_BASE_VECTOR_NORMALIZED "Gets whether the Vector is normalized."
#define DOC_BASE_VECTOR_NORMALIZE "ormalize () -> Vector\n\nCreates a normalized representation of this Vector."
#define DOC_BASE_VECTOR_NORMALIZE_IP "ormalize_ip () -> None\n\nNormalizes the Vector in place."
#define DOC_BASE_VECTOR_SLERP "slerp () -> Vector\n\n"
#define DOC_BASE_VECTOR_LERP "lerp () -> Vector\n\n"
#define DOC_BASE_VECTOR_DOT "dot (v) -> float\n\nCalculates the dot product of the Vector and the passed argument."
#define DOC_BASE_VECTOR_SCALE_TO "scale_to (length) -> Vector\n\nScales the Vector to match the passed length."
#define DOC_BASE_VECTOR_REFLECT "reflect () -> Vector\n\nCreates a reflected representation of the Vector."
#define DOC_BASE_VECTOR_REFLECT_IP "reflect_ip () -> None\n\nReflects the Vector in place."
#define DOC_BASE_VECTOR_DISTANCE "distance (v) -> float\n\nCalculates the distance between two vectors."
#define DOC_BASE_VECTOR_DISTANCE_SQUARED "distance_squared () -> None\n\nCalculates the squared distance between two vectors."
#define DOC_BASE_VECTOR2 "Vector2 () -> Vector2\n\nCreates a new Vector2.\n\nA simple 2D vector containing only two elements."
#define DOC_BASE_VECTOR2_DIMENSION "Gets the dimensions of the Vector2."
#define DOC_BASE_VECTOR2_ELEMENTS "Gets or sets the elements of the Vector2.\n\nThis will only set a maximum of two values."
#define DOC_BASE_VECTOR2_X "Gets or sets first element of the Vector2."
#define DOC_BASE_VECTOR2_Y "Gets or sets second element of the Vector2."
#define DOC_BASE_VECTOR2_ROTATE "rotate (angle) -> Vector2\n\nRotates the Vector2 by the passed degrees."
#define DOC_BASE_VECTOR2_ROTATE_IP "rotate_ip (angle) -> Vector2\n\nRotates the Vector2 by the passed degrees in place."
#define DOC_BASE_VECTOR2_AS_POLAR "as_polar () -> float, float\n\nGets the polar coordinate representation of the Vector2."
#define DOC_BASE_VECTOR2_ANGLE_TO "angle_to (v) -> float\n\nCalculates the angle (in degrees) between two Vector2 objects."
#define DOC_BASE_VECTOR2_CROSS "cross (v) -> Vector2\n\nCreates the cross product of the two Vector2 objects."
#define DOC_BASE_VECTOR3 "Vector3 () -> Vector3\n\nCreates a new Vector3.\n\nA simple 3D vector containing only three elements."
#define DOC_BASE_VECTOR3_DIMENSION "Gets the dimensions of the Vector3."
#define DOC_BASE_VECTOR3_ELEMENTS "Gets or sets the elements of the Vector3.\n\nThis will only set a maximum of three values."
#define DOC_BASE_VECTOR3_X "Gets or sets first element of the Vector3."
#define DOC_BASE_VECTOR3_Y "Gets or sets second element of the Vector3."
#define DOC_BASE_VECTOR3_Z "Gets or sets third element of the Vector3."
#define DOC_BASE_VECTOR3_ROTATE_X "rotate_x (angle) -> Vector3\n\nRotates the Vector3 by the passed degrees around the x-axis."
#define DOC_BASE_VECTOR3_ROTATE_X_IP "rotate_x_ip (angle) -> None\n\nRotates the Vector3 by the passed degrees in place around the x-axis."
#define DOC_BASE_VECTOR3_ROTATE_Y "rotate_y (angle) -> Vector3\n\nRotates the Vector3 by the passed degrees around the y-axis."
#define DOC_BASE_VECTOR3_ROTATE_Y_IP "rotate_y_ip (angle) -> None\n\nRotates the Vector3 by the passed degrees in place around the y-axis."
#define DOC_BASE_VECTOR3_ROTATE_Z "rotate_z (angle) -> Vector3\n\nRotates the Vector3 by the passed degrees around the z-axis."
#define DOC_BASE_VECTOR3_ROTATE_Z_IP "rotate_z_ip (angle) -> None\n\nRotates the Vector3 by the passed degrees in place around the z-axis."
#define DOC_BASE_VECTOR3_ROTATE "rotate (angle, axis) -> Vector3\n\nRotates the Vector3 by the passed degrees around the passed axis vector."
#define DOC_BASE_VECTOR3_ROTATE_IP "rotate_ip (angle, axis) -> Vector3\n\nRotates the Vector3 by the passed degrees in place around the passed axis vector."
#define DOC_BASE_VECTOR3_ANGLE_TO "angle_to (v) -> float\n\nCalculates the angle between two vectors in degrees"
#define DOC_BASE_VECTOR3_CROSS "cross (v) -> Vector3\n\nCalculates the cross product between the two Vector3 instances."
#define DOC_BASE_VECTOR3_AS_SPHERICAL "as_spherical () -> float, float, float\n\nGets the sperhical coordinate representation of the Vector3."

#endif
